@@ -167,7 +167,7 @@ def iou_cost(tracks, detections, track_indices=None,
     cost_matrix = np.zeros((len(track_indices), len(detection_indices)))
     for row, track_idx in enumerate(track_indices):
         if tracks[track_idx].time_since_update > 1:
-            cost_matrix[row, :] = linear_assignment.INFTY_COST
+            cost_matrix[row, :] = INFTY_COST
             continue
 
         bbox = tracks[track_idx].to_tlwh()
@@ -567,7 +567,7 @@ def gate_cost_matrix(
 
     """
     gating_dim = 2 if only_position else 4
-    gating_threshold = kalman_filter.chi2inv95[gating_dim]
+    gating_threshold = chi2inv95[gating_dim]
     measurements = np.asarray(
         [detections[i].to_xyah() for i in detection_indices])
     for row, track_idx in enumerate(track_indices):
@@ -930,7 +930,7 @@ class Track:
 
         Parameters
         ----------
-        kf : kalman_filter.KalmanFilter
+        kf : KalmanFilter
             The Kalman filter.
 
         """
@@ -944,7 +944,7 @@ class Track:
 
         Parameters
         ----------
-        kf : kalman_filter.KalmanFilter
+        kf : KalmanFilter
             The Kalman filter.
         detection : Detection
             The associated detection.
@@ -1006,7 +1006,7 @@ class Tracker:
         Maximum number of missed misses before a track is deleted.
     n_init : int
         Number of frames that a track remains in initialization phase.
-    kf : kalman_filter.KalmanFilter
+    kf : KalmanFilter
         A Kalman filter to filter target trajectories in image space.
     tracks : List[Track]
         The list of active tracks at the current time step.
@@ -1019,7 +1019,7 @@ class Tracker:
         self.max_age = max_age
         self.n_init = n_init
 
-        self.kf = kalman_filter.KalmanFilter()
+        self.kf = KalmanFilter()
         self.tracks = []
         self._next_id = 1
 
@@ -1072,7 +1072,7 @@ class Tracker:
             features = np.array([dets[i].feature for i in detection_indices])
             targets = np.array([tracks[i].track_id for i in track_indices])
             cost_matrix = self.metric.distance(features, targets)
-            cost_matrix = linear_assignment.gate_cost_matrix(
+            cost_matrix = gate_cost_matrix(
                 self.kf, cost_matrix, tracks, dets, track_indices,
                 detection_indices)
 
@@ -1086,7 +1086,7 @@ class Tracker:
 
         # Associate confirmed tracks using appearance features.
         matches_a, unmatched_tracks_a, unmatched_detections = \
-            linear_assignment.matching_cascade(
+            matching_cascade(
                 gated_metric, self.metric.matching_threshold, self.max_age,
                 self.tracks, detections, confirmed_tracks)
 
@@ -1098,7 +1098,7 @@ class Tracker:
             k for k in unmatched_tracks_a if
             self.tracks[k].time_since_update != 1]
         matches_b, unmatched_tracks_b, unmatched_detections = \
-            linear_assignment.min_cost_matching(
+            min_cost_matching(
                 iou_matching.iou_cost, self.max_iou_distance, self.tracks,
                 detections, iou_track_candidates, unmatched_detections)
 
