@@ -36,7 +36,7 @@ def Track(boxes, classes, confidence, frame):
     # Run non-maxima suppression.
     boxes = np.array([d.tlwh for d in detections])
     scores = np.array([d.confidence for d in detections])
-    indices = preprocessing.non_max_suppression(boxes, nms_max_overlap, scores)
+    indices = non_max_suppression(boxes, nms_max_overlap, scores)
     detections = [detections[i] for i in indices]
     
     if tracking:
